import { Construct } from "constructs";
import { WeightedLatencyARecord } from "../../aws-route53";
import { StandardDomainName } from "./standard-domain-name";
import { HttpApi } from "@aws-cdk/aws-apigatewayv2-alpha";
export interface StandardApiGatewayProps {
    /**
     * The prefix of the domain to create the certificate and DNS record for.
     */
    readonly domainPrefix: string;
    /**
     * The zone of the domain to create the certificate and DNS record for.
     */
    readonly domainZone: string;
    /**
     * Setting this to false will change the weight of the DNS record created to 0. Default is true.
     *
     * @default - true
     */
    readonly enabled?: boolean;
    /**
     * Name of the API Gateway. One will be generated if not provided.
     */
    readonly apiName?: string;
    /**
     * Setting this to true will suppress the creation of default tags on resources
     * created by this construct. Default is false.
     *
     * @default - false
     */
    readonly suppressTagging?: boolean;
}
/**
 * Abstraction that creates an API Gateway with a custom domain name, certificate and latency based routing
 * record in Route53.
 */
export declare class StandardApiGateway extends Construct {
    readonly domainName: StandardDomainName;
    readonly record: WeightedLatencyARecord;
    readonly gateway: HttpApi;
    constructor(scope: Construct, id: string, props: StandardApiGatewayProps);
}
